@@ -1,12 +1,105 @@
 package Lingua::EN::NameCase;
 
+=head1 NAME
+
+Lingua::EN::NameCase - Correctly case a person's name from UPERCASE or lowcase
+
+=cut
+
 use warnings;
 use strict;
 use locale;
 
 use vars qw( $VERSION @ISA @EXPORT @EXPORT_OK $HEBREW $SPANISH $ROMAN $POSTNOMINAL );
 
-$VERSION = '1.20';
+=head1 VERSION
+
+Version 1.21
+
+=cut
+
+our $VERSION = '1.21';
+
+=head1 SYNOPSIS
+
+    # Working with scalars; complementing lc and uc.
+
+    use Lingua::EN::NameCase qw( nc );
+
+    $FixedCasedName  = nc( $OriginalName );
+
+    $FixedCasedName  = nc( \$OriginalName );
+
+    # Working with arrays or array references.
+
+    use Lingua::EN::NameCase 'NameCase';
+
+    $FixedCasedName  = NameCase( $OriginalName );
+    @FixedCasedNames = NameCase( @OriginalNames );
+
+    $FixedCasedName  = NameCase( \$OriginalName );
+    @FixedCasedNames = NameCase( \@OriginalNames );
+
+    NameCase( \@OriginalNames ) ; # In-place.
+
+    # NameCase will not change a scalar in-place, i.e.
+    NameCase( \$OriginalName ) ; # WRONG: null operation.
+
+    $Lingua::EN::NameCase::SPANISH = 1;
+    # Now 'El' => 'El' instead of (default) Greek 'El' => 'el'.
+    # Now 'La' => 'La' instead of (default) French 'La' => 'la'.
+
+    $Lingua::EN::NameCase::HEBREW = 0;
+    # Now 'Aharon BEN Amram Ha-Kohein' => 'Aharon Ben Amram Ha-Kohein'
+    #   instead of (default) => 'Aharon ben Amram Ha-Kohein'.
+
+    $Lingua::EN::NameCase::ROMAN = 0;
+    # Now 'Li' => 'Li' instead of (default) 'Li' => 'LI'.
+
+    $Lingua::EN::NameCase::POSTNOMINAL = 0;
+    # Now 'PHD' => 'PhD' instead of (default) 'PHD' => 'Phd'.
+
+=head1 DESCRIPTION
+
+Forenames and surnames are often stored either wholly in UPPERCASE
+or wholly in lowercase. This module allows you to convert names into
+the correct case where possible.
+
+Although forenames and surnames are normally stored separately if they
+do appear in a single string, whitespace separated, NameCase and nc deal
+correctly with them.
+
+NameCase currently correctly name cases names which include any of the
+following:
+
+    Mc, Mac, al, el, ap, da, de, delle, della, di, du, del, der,
+    la, le, lo, van and von.
+
+It correctly deals with names which contain apostrophes and hyphens too.
+
+=head2 EXAMPLE FIXES
+
+    Original            Name Case
+    --------            ---------
+    KEITH               Keith
+    LEIGH-WILLIAMS      Leigh-Williams
+    MCCARTHY            McCarthy
+    O'CALLAGHAN         O'Callaghan
+    ST. JOHN            St. John
+
+plus "son (daughter) of" etc. in various languages, e.g.:
+
+    VON STREIT          von Streit
+    VAN DYKE            van Dyke
+    AP LLWYD DAFYDD     ap Llwyd Dafydd
+    etc.
+
+plus names with roman numerals (up to 89, LXXXIX), e.g.:
+
+    henry viii          Henry VIII
+    louis xiv           Louis XIV
+
+=cut
 
 #--------------------------------------------------------------------------
 # Modules
@@ -55,6 +148,13 @@ my @POST_NOMINAL_INITIALS = qw(
 #--------------------------------------------------------------------------
 # Functions
 
+=head2 NameCase
+
+Takes a scalar, scalarref, array or arrayref, and changes the case of the
+contents, as appropriate. Essentially a wrapper around nc().
+
+=cut
+
 sub NameCase {
     croak "Usage: \$SCALAR|\@ARRAY = NameCase [\\]\$SCALAR|\@ARRAY"
         if ref $_[0] and ( ref $_[0] ne 'ARRAY' and ref $_[0] ne 'SCALAR' );
@@ -87,6 +187,13 @@ sub NameCase {
     }
 }
 
+=head2 nc
+
+Takes a scalar or scalarref, and change the case of the name in the
+corresponding string appropriately.
+
+=cut
+
 sub nc {
     croak "Usage: nc [[\\]\$SCALAR]"
         if scalar @_ > 1 or ( ref $_[0] and ref $_[0] ne 'SCALAR' );
@@ -170,111 +277,6 @@ sub nc {
     $_;
 }
 
-1;
-
-__END__
-
-#--------------------------------------------------------------------------
-
-=head1 NAME
-
-Lingua::EN::NameCase - Correctly case a person's name from UPERCASE or lowcase
-
-=head1 SYNOPSIS
-
-    # Working with scalars; complementing lc and uc.
-
-    use Lingua::EN::NameCase qw( nc );
-
-    $FixedCasedName  = nc( $OriginalName );
-
-    $FixedCasedName  = nc( \$OriginalName );
-
-    # Working with arrays or array references.
-
-    use Lingua::EN::NameCase 'NameCase';
-
-    $FixedCasedName  = NameCase( $OriginalName );
-    @FixedCasedNames = NameCase( @OriginalNames );
-
-    $FixedCasedName  = NameCase( \$OriginalName );
-    @FixedCasedNames = NameCase( \@OriginalNames );
-
-    NameCase( \@OriginalNames ) ; # In-place.
-
-    # NameCase will not change a scalar in-place, i.e.
-    NameCase( \$OriginalName ) ; # WRONG: null operation.
-
-    $Lingua::EN::NameCase::SPANISH = 1;
-    # Now 'El' => 'El' instead of (default) Greek 'El' => 'el'.
-    # Now 'La' => 'La' instead of (default) French 'La' => 'la'.
-
-    $Lingua::EN::NameCase::HEBREW = 0;
-    # Now 'Aharon BEN Amram Ha-Kohein' => 'Aharon Ben Amram Ha-Kohein'
-    #   instead of (default) => 'Aharon ben Amram Ha-Kohein'.
-
-    $Lingua::EN::NameCase::ROMAN = 0;
-    # Now 'Li' => 'Li' instead of (default) 'Li' => 'LI'.
-
-    $Lingua::EN::NameCase::POSTNOMINAL = 0;
-    # Now 'PHD' => 'PhD' instead of (default) 'PHD' => 'Phd'.
-
-=head1 DESCRIPTION
-
-Forenames and surnames are often stored either wholly in UPPERCASE
-or wholly in lowercase. This module allows you to convert names into
-the correct case where possible.
-
-Although forenames and surnames are normally stored separately if they
-do appear in a single string, whitespace separated, NameCase and nc deal
-correctly with them.
-
-NameCase currently correctly name cases names which include any of the
-following:
-
-    Mc, Mac, al, el, ap, da, de, delle, della, di, du, del, der,
-    la, le, lo, van and von.
-
-It correctly deals with names which contain apostrophes and hyphens too.
-
-=head2 EXAMPLE FIXES
-
-    Original            Name Case
-    --------            ---------
-    KEITH               Keith
-    LEIGH-WILLIAMS      Leigh-Williams
-    MCCARTHY            McCarthy
-    O'CALLAGHAN         O'Callaghan
-    ST. JOHN            St. John
-
-plus "son (daughter) of" etc. in various languages, e.g.:
-
-    VON STREIT          von Streit
-    VAN DYKE            van Dyke
-    AP LLWYD DAFYDD     ap Llwyd Dafydd
-    etc.
-
-plus names with roman numerals (up to 89, LXXXIX), e.g.:
-
-    henry viii          Henry VIII
-    louis xiv           Louis XIV
-
-=head1 METHODS
-
-=over
-
-=item * NameCase
-
-Takes a scalar, scalarref, array or arrayref, and changes the case of the
-contents, as appropriate. Essentially a wrapper around nc().
-
-=item * nc
-
-Takes a scalar or scalarref, and change the case of the name in the
-corresponding string appropriately.
-
-=back
-
 =head1 BUGS
 
 The module covers the rules that I know of. There are probably a lot
@@ -286,6 +288,42 @@ data 'cleaner' it may be all you need.
 
 Use Kim Ryan's L<Lingua::EN::NameParse> for any really sophisticated name parsing.
 
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc Lingua::EN::NameCase
+
+You can also look for information at:
+
+=over 4
+
+=item * MetaCPAN
+
+L<https://metacpan.org/release/Lingua-EN-NameCase>
+
+=item * RT: CPAN's request tracker
+
+L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=Lingua-EN-NameCase>
+
+=item * CPANTS
+
+L<http://cpants.cpanauthors.org/dist/Lingua-EN-NameCase>
+
+=item * CPAN Testers' Matrix
+
+L<http://matrix.cpantesters.org/?dist=Lingua-EN-NameCase>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/Lingua-EN-NameCase>
+
+=item * CPAN Testers Dependencies
+
+L<http://deps.cpantesters.org/?module=Lingua::EN::NameCase>
+
+=back
+
 =head1 AUTHOR
 
   1998-2014    Mark Summerfield <summer@qtrac.eu>
@@ -306,3 +344,6 @@ This distribution is free software; you can redistribute it and/or
 modify it under the Artistic Licence v2.
 
 =cut
+
+1;
+
